@@ -43,6 +43,7 @@ from h_UI_searchDialog import *
 from h_UI_mainMenuDialog import *
 from h_UI_detailsWindow import *
 from h_UI_welcomeScreen import *
+from math_helper import *
 
 try:
     from h_UI_selectContact import *
@@ -62,7 +63,7 @@ gtk.gdk.threads_init()
 
 
 name = "yosmapa"
-version = "0.19-20"
+version = "0.20-3"
 
 
 
@@ -145,7 +146,10 @@ maps_source = [
     ["http://tile.osmosnimki.ru/kosmo/#Z/#X/#Y.png","tile osmosnimki ru"],
     ["http://a.tile.cloudmade.com/fd093e52f0965d46bb1c6c6281022199/1/256/#Z/#X/#Y.png","a tile cloudmade"],
     ["http://b.tile.cloudmade.com/BC9A493B41014CAABB98F0471D759707/999/256/#Z/#X/#Y.png","night - b tile claudmade"],
-
+    ["http://e.maptile.maps.svc.ovi.com/maptiler/v2/maptile/newest/normal.day/#Z/#X/#Y/256/png8", "ovi map"],
+    ["http://d.maptile.maps.svc.ovi.com/maptiler/v2/maptile/newest/hybrid.day/#Z/#X/#Y/256/png8", "ovi hybrid"],
+    ["http://d.maptile.maps.svc.ovi.com/maptiler/v2/maptile/newest/terrain.day/#Z/#X/#Y/256/png8","ovi terrain"],
+    ["http://b.maptile.maps.svc.ovi.com/maptiler/v2/maptile/newest/normal.day.transit/#Z/#X/#Y/256/png8y","ovi transit"]
     #[osmgpsmap.SOURCE_YAHOO_STREET, "Yahoo Maps"],
     #[osmgpsmap.SOURCE_YAHOO_SATELLITE, "Yahoo Satellite"],
     #[osmgpsmap.SOURCE_YAHOO_HYBRID, "Yahoo Hybrid"]
@@ -161,18 +165,32 @@ class YosmapaOSD(gobject.GObject, osmgpsmap.GpsMapLayer):
         gobject.GObject.__init__(self)
         self.osmMapa = osmMapa
 
-        self.plugin_ico_yoffset = 50
+        self.plugin_ico_yoffset = 100
         self.plugin_ico_h = 60
         self.plugin_ico_test = 48
 
-        self.pb_plus = cairo.ImageSurface.create_from_png( './imgs/i_plus.png' )
-        self.pb_min = cairo.ImageSurface.create_from_png( './imgs/i_min.png' )
-        self.pb_gps_on = cairo.ImageSurface.create_from_png( './imgs/i_gps_on.png' )
-        self.pb_gps = cairo.ImageSurface.create_from_png( './imgs/i_gps.png' )
-        self.pb_menu = cairo.ImageSurface.create_from_png( './imgs/ico_config2_64_64.png' )
+
+        self.pb_plus = cairo.ImageSurface.create_from_png( './imgs/ico_mag_plus2_96_96.png' )
+        self.pb_min = cairo.ImageSurface.create_from_png( './imgs/ico_mag_min2_96_96.png' )
+        self.pb_gps_on = cairo.ImageSurface.create_from_png( './imgs/ico_gps_on_64_64.png' )
+        self.pb_gps = cairo.ImageSurface.create_from_png( './imgs/ico_gps_off_64_64.png' )
+        self.pb_menu = cairo.ImageSurface.create_from_png( './imgs/ico_config2_48_48.png' )
 
         self.pb_find = cairo.ImageSurface.create_from_png( './imgs/ico_find2_48_48.png' )
         self.pb_clean = cairo.ImageSurface.create_from_png( './imgs/ico_clean_48_48.png' )
+        
+        
+        self.osd_ico = {
+            'zoom_in':      [self.pb_plus,  -1, 0, "zoom in",      self.pb_plus.get_width(),   self.pb_plus.get_height()],
+            'zoom_out':     [self.pb_min, 0, 0, "zoom out",         self.pb_min.get_width(),    self.pb_min.get_height()],
+            'gps_on':       [self.pb_gps_on,  -1, 100, "gps lock", self.pb_gps_on.get_width(), self.pb_gps_on.get_height()],
+            'gps_off':      [self.pb_gps,  -1, 100, "gps free",    self.pb_gps.get_width(),    self.pb_gps.get_height()],
+            'menu':         [self.pb_menu,  -1, 260, "menu",       self.pb_menu.get_width(),   self.pb_menu.get_height()],
+            'find':         [self.pb_find,  -1, 340, "find",       self.pb_find.get_width(),   self.pb_find.get_height()],
+            'clean':        [self.pb_clean,  -1, 340, "clean",     self.pb_clean.get_width(),  self.pb_clean.get_height()],
+            }
+        self.ico_draw = []
+        
         #self.show_find_results
 
         self.make_drawing = 1
@@ -189,14 +207,77 @@ class YosmapaOSD(gobject.GObject, osmgpsmap.GpsMapLayer):
     
                 self.size = gdkdrawable.get_size()
                 CONFIG['width'] = self.size[0]
+                ws = CONFIG['width']
                 CONFIG['height'] = self.size[1]
-                x = self.size[0]-64
-    
+                hs = CONFIG['height'] 
+                
+                aspect = 1.0
+                corner_radius = 4.0
+                M_PI = 3.14159265
+                radius = corner_radius / aspect
+                degrees = M_PI / 180.0
+                
+                    
                 cr = gdkdrawable.cairo_create()
                 self.gdkdrawable = gdkdrawable
+                
+                    
     
+                self.ico_draw = [
+                            "zoom_in", "zoom_out","menu"
+                            ]
+                if self.osmMapa.get_gpslock():
+                    self.ico_draw.append("gps_on")
+                else:
+                    self.ico_draw.append("gps_off")
+                if len(self.osmMapa.find_plugins) > 0:
+                    if len(self.osmMapa.show_find_results) > 0:
+                        self.ico_draw.append("clean")
+                    else:
+                        self.ico_draw.append("find")
+                    
+                
+                
+                for iName in self.ico_draw:
+                    item = self.osd_ico[iName]
+                    x = item[1]
+                    if x<0: x+=ws-item[4]
+                    y = item[2]
+                                        
+                    cr.set_source_surface( item[0],x,y )
+                    cr.paint()
+                    
+                    
+                                    
+                
+                
+                
+                """
+                xb = CONFIG['width']-60
+                yb = -5
+                width = 64
+                height = 230
+                aspect = 1.0
+                corner_radius = 4.0
+                M_PI = 3.14159265
+    
+                radius = corner_radius / aspect
+                degrees = M_PI / 180.0
+                
+                cr.arc (xb + width - radius, yb + height - radius, radius, 90 * degrees, 90 * degrees)
+                cr.arc (xb + radius, yb + height - radius, radius, 90 * degrees, 180 * degrees)
+                cr.arc (xb + radius, yb + radius, radius, 180 * degrees, 270 * degrees)
+                cr.arc (xb+ width - radius, yb + radius, radius, -90 * degrees, -90 * degrees)
+                cr.set_source_rgba (1,1,1,0.6)
+                cr.fill_preserve ()
+                cr.set_source_rgba (0.0, 0.0, 0.0,0.6)
+                cr.set_line_width (1.0)
+                cr.stroke ()
+                
+                
                 cr.set_source_surface( self.pb_plus, x,10 )
                 cr.paint()
+                
     
                 if gpsPresent:
                     if self.osmMapa.get_gpslock() == 1:
@@ -216,15 +297,18 @@ class YosmapaOSD(gobject.GObject, osmgpsmap.GpsMapLayer):
                 cr.paint()
                 cr.set_source_surface( self.pb_menu, x,self.size[1]-100 )
                 cr.paint()
-    
+                
+                
                 if len(self.osmMapa.find_plugins) > 0:
                     if len(self.osmMapa.show_find_results) > 0:
                         cr.set_source_surface( self.pb_clean, x+10,self.size[1]-160 )
                     else:
                         cr.set_source_surface( self.pb_find, x+10,self.size[1]-160 )
                     cr.paint()
+                """
     
                 plug_nr = 0
+                plug_to_add = []
                 for plugin in self.osmMapa.plugins_list:
                     plugin_name = plugin[1]
                     if CONFIG[plugin_name] and plugin[2]:
@@ -233,21 +317,44 @@ class YosmapaOSD(gobject.GObject, osmgpsmap.GpsMapLayer):
                         if plugin[3] <> None:
                             try:
                                 if plugin[0].ui_menu_left:
-                                    cr.set_source_surface( plugin[2], 2, (plug_nr*self.plugin_ico_h)+self.plugin_ico_yoffset )
-                                    cr.paint()
+                                    #cr.set_source_surface( plugin[2], 2, (plug_nr*self.plugin_ico_h)+self.plugin_ico_yoffset )
+                                    #cr.paint()
+                                    plug_to_add( [plugin[2], 2, (plug_nr*self.plugin_ico_h)+self.plugin_ico_yoffset] )
                                     plug_nr+=1
                             except:
-                                    cr.set_source_surface( plugin[2], 2, (plug_nr*self.plugin_ico_h)+self.plugin_ico_yoffset )
-                                    cr.paint()
+                                    #cr.set_source_surface( plugin[2], 2, (plug_nr*self.plugin_ico_h)+self.plugin_ico_yoffset )
+                                    #cr.paint()
+                                    plug_to_add.append( [ plugin[2], 2, (plug_nr*self.plugin_ico_h)+self.plugin_ico_yoffset ] )
                                     plug_nr+=1
     
+                if plug_to_add:
+                    xb = -10
+                    yb = self.plugin_ico_yoffset-5
+                    width = 46
+                    height = plug_nr*self.plugin_ico_h-20
+                    
+                    cr.arc (xb + radius, yb + radius, radius, 270 * degrees, 270 * degrees)
+                    cr.arc (xb+ width - radius, yb + radius, radius, -90 * degrees, 0 * degrees)
+                    cr.arc (xb + width - radius, yb + height - radius, radius, 0 * degrees, 90 * degrees)
+                    cr.arc (xb + radius, yb + height - radius, radius, 90 * degrees, 90 * degrees)
+                    cr.set_source_rgba (1,1,1,0.6)
+                    cr.fill_preserve ()
+                    cr.set_source_rgba (0.0, 0.0, 0.0,0.6)
+                    cr.set_line_width (1.0)
+                    cr.stroke ()
+                
+    
+                for p in plug_to_add:
+                    cr.set_source_surface( p[0], p[1], p[2] )
+                    cr.paint()
+                
     
                 if self.osmMapa.osm.props.tiles_queued != 0:
                     str = "Downloading images (%i)" % self.osmMapa.osm.props.tiles_queued
                     cr.set_source_rgb(0.0, 0.0, 0.0)
                     cr.select_font_face("Georgia")
                     cr.set_font_size(15)
-                    cr.move_to(10,15)
+                    cr.move_to(10,hs-40)
                     cr.show_text(str)
                 if timing_osd:
                     print "YosmapaOSD do_draw in:",(time.time()-t)
@@ -269,6 +376,48 @@ class YosmapaOSD(gobject.GObject, osmgpsmap.GpsMapLayer):
         #print "dummy event ",gpsmap, gdkeventbutton
         x = self.size[0]-64
         #print "x start",x,"bt press at",gdkeventbutton.x
+        
+        print self.ico_draw
+        action_exec = ""
+        mx = gdkeventbutton.x
+        my = gdkeventbutton.y
+        ws = self.size[0]
+        for iName in self.ico_draw:
+            item = self.osd_ico[iName]
+            xl = item[1]
+            if xl<0: xl+=ws-item[4]
+            xr = xl+item[4]
+            yt = item[2]
+            yb = yt+item[5]
+            
+            if mx>xl and mx<xr and my>yt and my<yb:
+                action_exec = item[3]
+                break
+            
+        print "action exec",action_exec
+        
+        if action_exec <> "":
+            if action_exec == "zoom in":
+                self.osmMapa.zoom_in_clicked(None)
+            elif action_exec == "zoom out":
+                self.osmMapa.zoom_out_clicked(None)
+            elif action_exec == "menu":
+                self.osmMapa.build_mainMenu()
+            elif action_exec == "gps free" or action_exec == "gps lock":
+                if self.osmMapa.get_gpslock():
+                    self.osmMapa.set_gpslock( 0 )
+                else:
+                    self.osmMapa.set_gpslock( 1 )
+                    try:
+                        if gpsPresent:
+                            self.osmMapa.osm.set_center( gps.lat, gps.lon )
+                    except:
+                        print "gps get trac kupa"
+            elif action_exec == "find":
+                self.osmMapa.build_search()
+            elif action_exec == "clean":
+                self.osmMapa.build_search()
+        """
         if gdkeventbutton.x >= x:
             if gdkeventbutton.y>10 and gdkeventbutton.y<70:
                 print "bt plus"
@@ -297,8 +446,8 @@ class YosmapaOSD(gobject.GObject, osmgpsmap.GpsMapLayer):
                 #dialog.run()
                 #dialog.destroy()
                 #print "response from dialog [",res,"]"
-
-        elif gdkeventbutton.x <= 52:
+        """
+        if mx <= 52:
             plug_nr = 0
             for plugin in self.osmMapa.plugins_list:
                 plugin_name = plugin[1]
@@ -314,7 +463,7 @@ class YosmapaOSD(gobject.GObject, osmgpsmap.GpsMapLayer):
                         ico = plugin[0].ico
                         w = plugin[0].get_menu_widgets(self)
                         y = (plug_nr*self.plugin_ico_h)+self.plugin_ico_yoffset
-                        if gdkeventbutton.y < (y+self.plugin_ico_test) and gdkeventbutton.y > y:
+                        if my < (y+self.plugin_ico_test) and my > y:
                             print "clicked on plugin nr ",plug_nr," name:", plugin_name
 
                             try:
@@ -358,8 +507,8 @@ class YosmapaOSD(gobject.GObject, osmgpsmap.GpsMapLayer):
                     except:
                         pass
         else:
-            x = gdkeventbutton.x
-            y = gdkeventbutton.y
+            x = mx
+            y = my
             t = time.time()
             self.osmMapa.cliked_at_xyt = [ x,y, t ]
             print "click at :",x,",",y
@@ -400,7 +549,7 @@ gobject.type_register(YosmapaOSD)
 
 
 
-class UI(hildon.StackableWindow):
+class UI(hildon.StackableWindow, math_helper):
 
     def dont_sleep(self):
         f = open( "/sys/class/backlight/acx565akm/brightness", "r")
@@ -432,7 +581,7 @@ class UI(hildon.StackableWindow):
             self.window_is_fullscreen = True
 
     def get_home(self):
-        return home
+        return os.path.expanduser("~")
     def get_config(self):
         return CONFIG
     def set_config(self,str, val):
@@ -682,14 +831,18 @@ class UI(hildon.StackableWindow):
             if len(self.show_find_results ) == 1:
                 p = self.show_find_results[0]
                 self.osm.set_center_and_zoom(p[0],p[1], 17 )
+                if not ico and p[4]:
+                    ico = p[4]
+                    f_name = "%s/.yosmapa_0.18.conf_%s.jpg" % (self.get_home(), md5.new(CONFIG['search']).hexdigest() )
+                    ico.save( f_name, "png", {}  )
             else:
                 t_lt, t_ln, b_lt, b_ln = 0.0, 0.0, 0.0, 0.0
                 for i,p in enumerate(self.show_find_results):
                     p[6] = 0
                     if not ico and p[4]:
                         ico = p[4]
-                        f_name = "%s_%s.jpg" % (home, md5.new(CONFIG['search']).hexdigest() )
-                        ico.save( f_name, "png", {"quality":"100"}  )
+                        f_name = "%s/.yosmapa_0.18.conf_%s.jpg" % (self.get_home(), md5.new(CONFIG['search']).hexdigest() )
+                        ico.save( f_name, "png", {}  )
 
                     if i == 0:
                         t_lt, t_ln, b_lt, b_ln = p[0],p[1],p[0],p[1]
@@ -845,27 +998,12 @@ class UI(hildon.StackableWindow):
 
    #-------------------------------------------------------------------
 
-
-
     def get_may_current_ll(self):
         if gpsPresent:
             if gps.lat <> 0.0 and gps.lon <> 0.0:
                 return [ gps.lat, gps.lon ]
-
-
         return [ self.osm.props.latitude, self.osm.props.longitude ]
 
-    def distance( self,lat1, lon1, lat2 = None, lon2 = None):
-        if lat2 == None and lon2 == None:
-            lat2,lon2 = self.get_may_current_ll()
-        try:
-            theta = lon1 - lon2
-            dist = math.sin(math.radians(lat1)) * math.sin(math.radians(lat2)) +  math.cos(math.radians(lat1)) * math.cos(math.radians(lat2)) * math.cos(math.radians(theta))
-            dist = math.acos(dist)
-            dist = math.degrees(dist)
-            return dist * 111.18957696
-        except:
-            return 0
     def distance_to_string(self, dis):
         if dis > 1.0:
             return "%.1f km"%dis
@@ -874,23 +1012,6 @@ class UI(hildon.StackableWindow):
             return "%i m"%dis
 
 
-    def cal_angle(self, lat0, lon0, lat1 = None, lon1 = None):
-        if lat1 == None and lon1 == None:
-            lat1,lon1 = self.get_may_current_ll()
-
-        deltax = lat1-lat0
-        deltay = lon0-lon1
-        M_PI = 3.14159265
-        angle_rad = math.atan2(deltax,deltay)+M_PI
-
-        return [ angle_rad, 0 ]
-
-
-    def cal_dist(self, lat0, lon0, lat1 = None, lon1 = None):
-        if lat1 == None and lon1 == None:
-            lat1,lon1 = self.get_may_current_ll()
-        return math.sqrt((lon0 - lon1)**2 + (lat0 - lat1)**2)
-
     def draw_arrow(self, gdkdrawable, lat, lon,rgba=[0.9,0.2,0.9,0.7], borderRgba=[0.0,0.4,0.4,0.3] ):
         print "\t\t\- UI draw_arrow"
         cr = gdkdrawable.cairo_create()
@@ -1060,10 +1181,13 @@ class UI(hildon.StackableWindow):
                self.osm = osmgpsmap.GpsMap(
                             map_source=CONFIG['engine_name']
                             )
+               #proxy_uri = "http://10.10.0.3:65433"
+               #print "proxy proxy proxy"
             else:
                 self.osm = osmgpsmap.GpsMap(
                         repo_uri=CONFIG['engine_name']
                         )
+            
 
             self.osd = osmgpsmap.GpsMapOsd(show_crosshair=(not self.get_gpslock() ))
             self.osm.layer_add(
@@ -1311,14 +1435,49 @@ gobject.type_register(PluginsLayer)
 
 
 
+"""
+db sample
+from db_helper import *
 
+class Mydb(db_helper):
+    def __init__(self):
+        db_helper.__init__(self)
+    
+    def set_struct(self):
+         self.struct = {
+            'wiki' : {
+                      'lat':     "float",
+                      'lon':     "float",
+                      'title':   "text",
+                      'summary': "text",
+                      'url':     "text",
+                      'rank':    "int"                      
+                      }
+            }
+"""
 
 
 
 if __name__ == "__main__":
     t = time.time()
     print "__main__"
-
+    
+    """
+    db sample
+    db = Mydb()
+    t = time.time()
+    print db.insert('wiki',
+        {'lat':0.000043*t,
+         'lon': 0.00000002*t,
+         'title': "testy testy testy"
+         }       
+        )
+    
+    print db.select('wiki',"*","(id%2)=1")
+    print db.one_row('wiki', "id=10")['title']
+    print db.one_value('wiki', "title", "id=10")
+    """
+    
     config_load( CONFIG )
     u = UI()
     u.show_all()
@@ -1351,6 +1510,13 @@ if __name__ == "__main__":
     if os.name == "nt": gtk.gdk.threads_enter()
     print "Up and running in: ",(time.time()-t)
     gtk.main()
+    
+    if CONFIG['track_record'] and len(u.my_gps_track)>0:
+        p = u.get_plugin("gpx track")
+        d = gtk.Dialog()
+        p.on_save(None, d)
+    
+    
     if os.name == "nt": gtk.gdk.threads_leave()
     config_save( CONFIG )
 
@@ -1364,5 +1530,4 @@ if __name__ == "__main__":
         gtk.gdk.threads_leave()
 
         print "GPS kill it DONE"
-
-
+    
\ No newline at end of file
